==> 0.9.0&file=out_yasapi-0.9.0-src.tar.gz: out_yasapi-0.9.0/out_yasapi/yasapi_plugin_options.c <==
/*
 * yasapi_plugin_options.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static const Property gcaPluginPropertyList[]={
#if defined (YASAPI_DEBUG) // {
  { YASAPI_PROPERTY_DEBUG,&gcIntType,offsetof(PluginOptions,debug),0 },
#endif // }
  { L"id",&gcStringType,offsetof(PluginOptions,id),YASAPI_ID_SIZE },
  { L"mono2stereo",&gcIntType,offsetof(PluginOptions,mono2stereo),0 },
  { L"volume",&gcIntType,offsetof(PluginOptions,volume),0 },
  { L"audioclock",&gcIntType,offsetof(PluginOptions,audioclock),0 },
  { L"page",&gcIntType,offsetof(PluginOptions,page),0 },
  { L"posx",&gcIntType,offsetof(PluginOptions,posx),0 },
  { L"posy",&gcIntType,offsetof(PluginOptions,posy),0 },
#if defined (YASAPI_DEBUG) // {
  { L"sleep",&gcIntType,offsetof(PluginOptions,sleep),0 },
#endif // }
  { NULL,NULL,0,0 }
};

///////////////////////////////////////////////////////////////////////////////
int PluginOptionsCreate(PluginOptions *pOptions, const wchar_t *path,
    int debug)
{
  PropertyLoadConfig c;

  pOptions->path=path;
  pOptions->debug=debug;

  DWPRINTF(debug,1,L"  properties: \"%s\"\n",path);

  c.debug=pOptions->debug;
  c.path=pOptions->path;
  c.pData=pOptions;
  c.pDefault=PluginOptionsDefault();
  c.group=YASAPI_GROUP_GENERAL;
  c.pfx=L"  ";
  PropertyLoad(gcaPluginPropertyList,&c);

  return 0;
}

void PluginOptionsDestroy(PluginOptions *pOptions)
{
#if defined (YASAPI_DEBUG) // {
  if (pOptions->debug) {
    Sleep(pOptions->sleep);
    ConsoleClose();
  }
#endif // }
}

///////////////////////////////////////////////////////////////////////////////
void PluginOptionsSave(PluginOptions *pOptions)
{
  PropertySaveConfig c;

  c.path=pOptions->path;
  c.pData=pOptions;
  c.group=YASAPI_GROUP_GENERAL;
  PropertySave(gcaPluginPropertyList,&c);
}

///////////////////////////////////////////////////////////////////////////////
const PluginOptions *PluginOptionsDefault(void)
{
  static int initialized;
  static PluginOptions options;

  if (!initialized) {
    options.debug=0;
    options.mono2stereo=1;
    options.audioclock=1;
    options.page=0;
    options.posx=-1;
    options.posx=-1;
#if defined (YASAPI_DEBUG) // {
    options.sleep=5000;
#endif // }

    initialized=1;
  }

  return &options;
}

==> 0.10.0&file=out_yasapi-0.10.0-src.tar.gz: out_yasapi-0.10.0/out_yasapi/yasapi_plugin_options.c <==
/*
 * yasapi_plugin_options.c
 * Copyright (C) 2015 Peter Belkner <pbelkner@snafu.de>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA  02110-1301  USA
 */
#include <yasapi.h>

///////////////////////////////////////////////////////////////////////////////
static const Property gcaPluginPropertyList[]={
#if defined (YASAPI_DEBUG) // {
  { YASAPI_PROPERTY_DEBUG,&gcIntType,offsetof(PluginOptions,debug),0 },
#endif // }
  { L"id",&gcStringType,offsetof(PluginOptions,id),YASAPI_ID_SIZE },
  { L"mono2stereo",&gcIntType,offsetof(PluginOptions,bMono2Stereo),0 },
  { L"volume",&gcIntType,offsetof(PluginOptions,bVolume),0 },
  { L"audioclock",&gcIntType,offsetof(PluginOptions,bAudioClock),0 },
  { YASAPI_PROPERTY_VIS,&gcIntType,offsetof(PluginOptions,bVisualization),0 },
  { YASAPI_PROPERTY_PAGE,&gcIntType,offsetof(PluginOptions,page),0 },
  { YASAPI_PROPERTY_POSX,&gcIntType,offsetof(PluginOptions,posx),0 },
  { YASAPI_PROPERTY_POSY,&gcIntType,offsetof(PluginOptions,posy),0 },
#if defined (YASAPI_DEBUG) // {
  { L"sleep",&gcIntType,offsetof(PluginOptions,sleep),0 },
#endif // }
  { NULL,NULL,0,0 }
};

///////////////////////////////////////////////////////////////////////////////
int PluginOptionsCreate(PluginOptions *pOptions, const wchar_t *path,
    int debug)
{
  PropertyLoadConfig c;

  pOptions->path=path;
  pOptions->debug=debug;

  DWPRINTF(debug,2,L"  properties: \"%s\"\n",path);

  c.debug=pOptions->debug;
  c.path=pOptions->path;
  c.pData=pOptions;
  c.pDefault=PluginOptionsDefault();
  c.group=YASAPI_GROUP_GENERAL;
  c.pfx=L"  ";
  PropertyLoad(gcaPluginPropertyList,&c);

  return 0;
}

void PluginOptionsDestroy(PluginOptions *pOptions)
{
#if defined (YASAPI_DEBUG) // {
  if (pOptions->debug) {
    Sleep(pOptions->sleep);
    ConsoleClose();
  }
#endif // }
}

///////////////////////////////////////////////////////////////////////////////
void PluginOptionsSave(PluginOptions *pOptions)
{
  PropertySaveConfig c;

  c.path=pOptions->path;
  c.pData=pOptions;
  c.group=YASAPI_GROUP_GENERAL;
  PropertySave(gcaPluginPropertyList,&c);
}

///////////////////////////////////////////////////////////////////////////////
const PluginOptions *PluginOptionsDefault(void)
{
  static int initialized;
  static PluginOptions options;

  if (!initialized) {
    options.debug=0;
    options.bMono2Stereo=TRUE;
    options.bAudioClock=TRUE;
    options.bVisualization=TRUE;
    options.page=0;
    options.posx=-1;
    options.posy=-1;
#if defined (YASAPI_DEBUG) // {
    options.sleep=5000;
#endif // }

    initialized=1;
  }

  return &options;
}
